# EnsembleSwarm

[![PyPI release](https://github.com/gperdrizet/ensembleswarm/actions/workflows/publish_pypi.yml/badge.svg)](https://github.com/gperdrizet/ensembleswarm/actions/workflows/publish_pypi.yml) [![Python CI](https://github.com/gperdrizet/ensembleswarm/actions/workflows/python_ci.yml/badge.svg)](https://github.com/gperdrizet/ensembleswarm/actions/workflows/python_ci.yml)[![Devcontainer](https://github.com/gperdrizet/ensembleswarm/actions/workflows/codespaces/create_codespaces_prebuilds/badge.svg)](https://github.com/gperdrizet/ensembleswarm/actions/workflows/codespaces/create_codespaces_prebuilds)

Utility for regression on tabular data, implementing ensembles of ensembles with various SciKit-learn estimators.

## 1. Installation

Install the pre-release alpha from PyPI with:

```bash
pip install ensembleswarm
```
